@@ -188,7 +188,7 @@ class Fade(Transform):
     This is the superclass of FadeIn and FadeOut; use those instead.
     """
     def __init__(self, is_in=True, duration=1e3, curve="linear", *,  degree=2):
-        assert curve in ("linear", "polynomial", "exponential")
+        assert curve in ("linear", "polynomial")
         self.is_in = is_in
         self.duration = duration
         self.curve = curve
@@ -199,17 +199,6 @@ class Fade(Transform):
             amp = np.linspace(0, 1, self.num_samples(audio.sample_rate))
         elif self.curve == "polynomial":
             amp = (np.linspace(0, 1, self.num_samples(audio.sample_rate))) ** self.degree
-        elif self.curve == "exponential":
-            if self.degree == 0: # reverts to linear:
-                amp = np.linspace(0, 1, self.num_samples(audio.sample_rate))
-            else:
-                amp = np.linspace(0, 1, self.num_samples(audio.sample_rate))
-                d = DB_to_Linear(self.degree) # TODO
-                env = d**(1-amp)
-                amp = (env - d)/(1-d)
-            # TODO eaqsier to use (e**(kx) - 1)/(e**k - 1) for some k
-            # then k > 0 is like polynomial of degree > 1
-            # k < 0 is like polynomial of degree < 1
         
         # fade in/out handler
         if self.is_in:
